#MagCalibration

This is a program to calibrate the effective pixel size for cryoEM data collected on gold foils.
Documentation and source code is availbale at www.mrc-lmb.cam.ac.uk/crusso/
Please cite...
